@@ -73,7 +73,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!("flqrgnkx" => 8108);
     test_part_two!("flqrgnkx" => 1242);
