@@ -44,7 +44,7 @@ pub fn solve(input: &mut Input) -> Result<String, String> {
 
 #[test]
 fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!(
                     "abcdef
