@@ -208,7 +208,7 @@ pub fn solve(input: &mut Input) -> Result<String, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!(
             "Step C must be finished before step A can begin.
